
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.019.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.3601"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => "6.30",
    "File::ShareDir::Install" => "0.06",
    "Module::Build" => "0.3601"
  },
  "dist_abstract" => "A static site generator",
  "dist_author" => [
    "Doug Bell <preaction\@cpan.org>"
  ],
  "dist_name" => "Statocles",
  "dist_version" => "0.016",
  "license" => "perl",
  "module_name" => "Statocles",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "Beam::Wire" => 0,
    "File::Copy::Recursive" => 0,
    "File::Share" => 0,
    "Git::Repository" => 0,
    "Import::Base" => 0,
    "List::MoreUtils" => 0,
    "Memoize" => 0,
    "Mojolicious" => 0,
    "Moo::Lax" => 0,
    "Path::Tiny" => "0.054",
    "Pod::Usage::Return" => 0,
    "Text::Markdown" => 0,
    "Time::Piece" => 0,
    "Type::Tiny" => 0,
    "Types::Path::Tiny" => 0,
    "YAML" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/statocles"
  ],
  "share_dir" => {
    "dist" => "share"
  },
  "test_requires" => {
    "Capture::Tiny" => 0,
    "Dir::Self" => 0,
    "Test::Compile" => 0,
    "Test::Most" => 0
  }
);


my %fallback_build_requires = (
  "Capture::Tiny" => 0,
  "Dir::Self" => 0,
  "Module::Build" => "0.3601",
  "Test::Compile" => 0,
  "Test::Most" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
